#[non_exhaustive]
pub enum CreateResponseHeadersPolicyErrorKind {
AccessDenied(AccessDenied),
InconsistentQuantities(InconsistentQuantities),
InvalidArgument(InvalidArgument),
ResponseHeadersPolicyAlreadyExists(ResponseHeadersPolicyAlreadyExists),
TooLongCspInResponseHeadersPolicy(TooLongCspInResponseHeadersPolicy),
TooManyCustomHeadersInResponseHeadersPolicy(TooManyCustomHeadersInResponseHeadersPolicy),
TooManyResponseHeadersPolicies(TooManyResponseHeadersPolicies),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateResponseHeadersPolicy operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDenied(AccessDenied)
Access denied.
InconsistentQuantities(InconsistentQuantities)
The value of Quantity and the size of Items don't match.
InvalidArgument(InvalidArgument)
An argument is invalid.
ResponseHeadersPolicyAlreadyExists(ResponseHeadersPolicyAlreadyExists)
A response headers policy with this name already exists. You must provide a unique name. To modify an existing response headers policy, use UpdateResponseHeadersPolicy.
TooLongCspInResponseHeadersPolicy(TooLongCspInResponseHeadersPolicy)
The length of the Content-Security-Policy header value in the response headers policy exceeds the maximum.
For more information, see Quotas (formerly known as limits) in the Amazon CloudFront Developer Guide.
TooManyCustomHeadersInResponseHeadersPolicy(TooManyCustomHeadersInResponseHeadersPolicy)
The number of custom headers in the response headers policy exceeds the maximum.
For more information, see Quotas (formerly known as limits) in the Amazon CloudFront Developer Guide.
TooManyResponseHeadersPolicies(TooManyResponseHeadersPolicies)
You have reached the maximum number of response headers policies for this Amazon Web Services account.
For more information, see Quotas (formerly known as limits) in the Amazon CloudFront Developer Guide.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code