Struct aws_sdk_cloudfront::error::InvalidRelativePath
source · [−]#[non_exhaustive]pub struct InvalidRelativePath { /* private fields */ }Expand description
The relative path is too big, is not URL-encoded, or does not begin with a slash (/).
Implementations
sourceimpl InvalidRelativePath
impl InvalidRelativePath
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture InvalidRelativePath.