Struct aws_sdk_cloudfront::input::delete_origin_request_policy_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeleteOriginRequestPolicyInput
Implementations
The unique identifier for the origin request policy that you are deleting. To get the
identifier, you can use ListOriginRequestPolicies.
The unique identifier for the origin request policy that you are deleting. To get the
identifier, you can use ListOriginRequestPolicies.
The version of the origin request policy that you are deleting. The version is the origin
request policy’s ETag value, which you can get using
ListOriginRequestPolicies, GetOriginRequestPolicy, or
GetOriginRequestPolicyConfig.
The version of the origin request policy that you are deleting. The version is the origin
request policy’s ETag value, which you can get using
ListOriginRequestPolicies, GetOriginRequestPolicy, or
GetOriginRequestPolicyConfig.
Consumes the builder and constructs a DeleteOriginRequestPolicyInput