Struct aws_sdk_cloudfront::model::StreamingLoggingConfig
source · [−]#[non_exhaustive]pub struct StreamingLoggingConfig { /* private fields */ }Expand description
A complex type that controls whether access logs are written for this streaming distribution.
Implementations
sourceimpl StreamingLoggingConfig
impl StreamingLoggingConfig
sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
Specifies whether you want CloudFront to save access logs to an Amazon S3 bucket. If you don't want to enable logging when you create a streaming distribution or if you want to disable logging for an existing streaming distribution, specify false for Enabled, and specify empty Bucket and Prefix elements. If you specify false for Enabled but you specify values for Bucket and Prefix, the values are automatically deleted.
sourcepub fn bucket(&self) -> Option<&str>
pub fn bucket(&self) -> Option<&str>
The Amazon S3 bucket to store the access logs in, for example, myawslogbucket.s3.amazonaws.com.
sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
An optional string that you want CloudFront to prefix to the access log filenames for this streaming distribution, for example, myprefix/. If you want to enable logging, but you don't want to specify a prefix, you still must include an empty Prefix element in the Logging element.
sourceimpl StreamingLoggingConfig
impl StreamingLoggingConfig
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture StreamingLoggingConfig.