#[non_exhaustive]pub struct CreateTrustStoreInputBuilder { /* private fields */ }Expand description
A builder for CreateTrustStoreInput.
Implementations
Sourceimpl CreateTrustStoreInputBuilder
impl CreateTrustStoreInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
A name for the trust store.
This field is required.Sourcepub fn ca_certificates_bundle_source(
self,
input: CaCertificatesBundleSource,
) -> Self
pub fn ca_certificates_bundle_source( self, input: CaCertificatesBundleSource, ) -> Self
The CA certificates bundle source for the trust store.
This field is required.Sourcepub fn set_ca_certificates_bundle_source(
self,
input: Option<CaCertificatesBundleSource>,
) -> Self
pub fn set_ca_certificates_bundle_source( self, input: Option<CaCertificatesBundleSource>, ) -> Self
The CA certificates bundle source for the trust store.
Sourcepub fn get_ca_certificates_bundle_source(
&self,
) -> &Option<CaCertificatesBundleSource>
pub fn get_ca_certificates_bundle_source( &self, ) -> &Option<CaCertificatesBundleSource>
The CA certificates bundle source for the trust store.
Sourcepub fn use_client_certificate_ocsp_endpoint(self, input: bool) -> Self
pub fn use_client_certificate_ocsp_endpoint(self, input: bool) -> Self
A Boolean that determines whether to use the CA certificate's OCSP endpoint to check certificate revocation status.
Sourcepub fn set_use_client_certificate_ocsp_endpoint(
self,
input: Option<bool>,
) -> Self
pub fn set_use_client_certificate_ocsp_endpoint( self, input: Option<bool>, ) -> Self
A Boolean that determines whether to use the CA certificate's OCSP endpoint to check certificate revocation status.
Sourcepub fn get_use_client_certificate_ocsp_endpoint(&self) -> &Option<bool>
pub fn get_use_client_certificate_ocsp_endpoint(&self) -> &Option<bool>
A Boolean that determines whether to use the CA certificate's OCSP endpoint to check certificate revocation status.
A complex type that contains zero or more Tag elements.
A complex type that contains zero or more Tag elements.
A complex type that contains zero or more Tag elements.
Sourcepub fn build(self) -> Result<CreateTrustStoreInput, BuildError>
pub fn build(self) -> Result<CreateTrustStoreInput, BuildError>
Consumes the builder and constructs a CreateTrustStoreInput.
Sourceimpl CreateTrustStoreInputBuilder
impl CreateTrustStoreInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateTrustStoreOutput, SdkError<CreateTrustStoreError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateTrustStoreOutput, SdkError<CreateTrustStoreError, HttpResponse>>
Sends a request with this input using the given client.